@@ -12,7 +12,7 @@
 
    ---------------------------------------------------------------------------
 
-   Copyright (C) 2003-2007  Volker C. Behr
+   Copyright (C) 2003-2008  Volker C. Behr
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -38,6 +38,9 @@
 
   
    HISTORY: 
+   2008-03-24 : 2.4.7      - corrected the exit codes to match CUPS' specifications,
+                             unmodified username passed to PostProcessing as 3rd arg,
+                             made PPD file auto-selectable via IEEE-1284 device id
    2007-05-04 : 2.4.6      - optimized default options for GS to produce PDFs
    2007-02-27 : 2.4.5      - enclosing parentheses () are removed from title,
                              set a more comprehensive identification string
@@ -612,11 +615,11 @@ int main(int argc, char *argv[]) {
   }
 
   if (init()) 
-    return -1;
+    return 5;
   log_event(CPDEBUG, "initialization finished", CPVERSION);
 
   if (argc==1) {
-    printf("file cups-pdf:/ \"Virtual PDF Printer\" \"CUPS-PDF\"\n"); 
+    printf("file cups-pdf:/ \"Virtual PDF Printer\" \"CUPS-PDF\" \"MFG:Generic;MDL:CUPS-PDF Printer;DES:Generic CUPS-PDF Printer;CLS:PRINTER;CMD:POSTSCRIPT;\"\n"); 
     log_event(CPSTATUS, "identification string sent", NULL);
     return 0;
   }
@@ -630,7 +633,7 @@ int main(int argc, char *argv[]) {
   user=calloc(size, sizeof(char));
   if (user == NULL) {
     (void) fputs("CUPS-PDF: failed to allocate memory\n", stderr);
-    return -2;
+    return 5;
   }  
   snprintf(user, size, "%s%s", conf.userprefix, argv[2]);
   passwd=getpwnam(user);
@@ -651,7 +654,7 @@ int main(int argc, char *argv[]) {
         free(user);
         if (logfp!=NULL)
           (void) fclose(logfp);
-        return -2;
+        return 5;
       }
       log_event(CPDEBUG, "unknown user", user);
       size=strlen(conf.anondirname)+4;
@@ -661,7 +664,7 @@ int main(int argc, char *argv[]) {
         free(user);
         if (logfp!=NULL)
           (void) fclose(logfp);
-        return -2;
+        return 5;
       }  
       snprintf(dirname, size, "%s", conf.anondirname);
       while (strlen(dirname) && ((dirname[strlen(dirname)-1] == '\n') ||
@@ -685,7 +688,7 @@ int main(int argc, char *argv[]) {
       free(user);
       if (logfp!=NULL)
         (void) fclose(logfp);
-      return -2;
+      return 5;
     }  
     while (strlen(dirname) && ((dirname[strlen(dirname)-1] == '\n') ||
            (dirname[strlen(dirname)-1] == '\r')))
@@ -698,7 +701,7 @@ int main(int argc, char *argv[]) {
     free(dirname);
     if (logfp!=NULL)
       (void) fclose(logfp);
-    return -2;
+    return 5;
   }
   log_event(CPDEBUG, "user information prepared", NULL);
 
@@ -709,7 +712,7 @@ int main(int argc, char *argv[]) {
     free(dirname);
     if (logfp!=NULL)
       (void) fclose(logfp);
-    return -3;
+    return 5;
   }
   snprintf(spoolfile, size, "%s/cups2pdf-%i", conf.spool, (int) getpid());
   log_event(CPDEBUG, "spoolfile name created", spoolfile);
@@ -720,7 +723,7 @@ int main(int argc, char *argv[]) {
       free(spoolfile);
       if (logfp!=NULL)
         (void) fclose(logfp);
-      return -4;
+      return 5;
     }
     log_event(CPDEBUG, "input data read from stdin", NULL);
   }
@@ -730,7 +733,7 @@ int main(int argc, char *argv[]) {
       free(spoolfile);
       if (logfp!=NULL)
         (void) fclose(logfp);
-      return -4;
+      return 5;
     }
     log_event(CPDEBUG, "input data read from file", argv[6]);
   }  
@@ -743,7 +746,7 @@ int main(int argc, char *argv[]) {
     free(spoolfile);
     if (logfp!=NULL)
       (void) fclose(logfp);
-    return -5;
+    return 5;
   }
   snprintf(outfile, size, "%s/%s.pdf", dirname, title);
   log_event(CPDEBUG, "output filename created", outfile);
@@ -757,7 +760,7 @@ int main(int argc, char *argv[]) {
     free(outfile);
     if (logfp!=NULL)
       (void) fclose(logfp);
-    return -6;
+    return 5;
   }
   snprintf(gscall, size, conf.gscall, conf.ghostscript, conf.pdfver, outfile, spoolfile);
   log_event(CPDEBUG, "ghostscript commandline built", gscall);
@@ -773,7 +776,7 @@ int main(int argc, char *argv[]) {
     free(gscall);
     if (logfp!=NULL)
       (void) fclose(logfp);
-    return -7;
+    return 5;
   }
   log_event(CPDEBUG, "TMPDIR set for GhostScript", getenv("TMPDIR"));
 
@@ -799,17 +802,17 @@ int main(int argc, char *argv[]) {
     log_event(CPDEBUG, "ghostscript has finished", title);
     if (chmod(outfile, mode)) {
       log_event(CPERROR, "failed to set file mode for PDF file (non fatal)", outfile);
-      return -101;
+      return 5;
     }
     log_event(CPDEBUG, "file mode set for user output", outfile);
     
     if (strlen(conf.postprocessing)) {
-      size=strlen(conf.postprocessing)+strlen(outfile)+strlen(passwd->pw_name)+3;
+      size=strlen(conf.postprocessing)+strlen(outfile)+strlen(passwd->pw_name)+strlen(argv[2])+3;
       ppcall=calloc(size, sizeof(char));
       if (ppcall == NULL) 
         log_event(CPERROR, "failed to allocate memory for postprocessing (non fatal)", NULL);
       else {
-        snprintf(ppcall, size, "%s %s %s", conf.postprocessing, outfile, passwd->pw_name);
+        snprintf(ppcall, size, "%s %s %s %s", conf.postprocessing, outfile, passwd->pw_name, argv[2]);
         log_event(CPDEBUG, "postprocessing commandline built", ppcall);
         size=system(ppcall);
         snprintf(title,BUFSIZE,"%d",size);
